Functor<F extends ForFunctor, A> class abstract

Implemented types
Implementers
Available extensions

Constructors

Functor()

Properties

DApplicative Applicative<F, A>

Available on Kind<F, A>, provided by the KindApplicativeFix extension

no setter
DFunctor Functor<F, A>

Available on Kind<F, A>, provided by the KindFunctorFix extension

no setter
DMonad Monad<F, A>

Available on Kind<F, A>, provided by the KindMonadFix extension

no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ap<C>(Kind<F, C Function(A)> f) Kind<F, C>

Available on Kind<F, A>, provided by the KindApplicativeFix extension

bind<B>(Kind<F, B> f(A)) Kind<F, B>

Available on Kind<F, A>, provided by the KindMonadFix extension

fmap<C>(C f(A)) Kind<F, C>
fmap<B>(B f(A)) Kind<F, B>

Available on Kind<F, A>, provided by the KindFunctorFix extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pure(A a) Kind<F, A>

Available on Kind<F, A>, provided by the KindApplicativeFix extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited