Monad<F extends ForMonad, A> class
abstract
- Implemented types
-
- Applicative<
F, A>
- Applicative<
- Available extensions
Constructors
- Monad()
Properties
-
DMonad
→ Monad<
F, A> -
Available on Kind<
F, A> , provided by the KindMonadFix extensionno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ap<
C> (Kind< F, C Function(A)> f) → Kind<F, C> -
inherited
-
bind<
C> (Kind< F, C> f(A)) → Kind<F, C> -
bind<
B> (Kind< F, B> f(A)) → Kind<F, B> -
Available on Kind<
F, A> , provided by the KindMonadFix extension -
fmap<
C> (C f(A)) → Kind< F, C> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pure(
A a) → Kind< F, A> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited